==> kdebase-3.1.4.tar.bz2: kdebase-3.1.4/kicker/ui/removebutton_mnu.cpp <==
/*****************************************************************

Copyright (c) 2001 Matthias Elter <elter@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#include <qregexp.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kglobal.h>
#include <kdebug.h>

#include "panelbutton.h"
#include "pluginmanager.h"
#include "pluginloader.h"
#include "containerarea.h"
#include "container_base.h"
#include "container_button.h"

#include "removebutton_mnu.h"
#include "removebutton_mnu.moc"

PanelRemoveButtonMenu::PanelRemoveButtonMenu( ContainerArea* cArea,
					      QWidget *parent, const char *name )
    : QPopupMenu( parent, name ), containerArea( cArea )
{
    connect( this, SIGNAL( activated( int ) ), SLOT( slotExec( int ) ) );
    connect( this, SIGNAL( aboutToShow() ), SLOT( slotAboutToShow() ) );

    containers.setAutoDelete( FALSE );
}

void PanelRemoveButtonMenu::slotAboutToShow()
{
    int id = 0;
    clear();

    containers = containerArea->containers( "URLButton" );
    QPtrList<BaseContainer> list = containerArea->containers( "ServiceButton" );
    for( QPtrListIterator<BaseContainer> it( list ); it.current() ; ++it )
	containers.append( *it );
    list = containerArea->containers( "ServiceMenuButton" );
    for( QPtrListIterator<BaseContainer> it( list ); it.current() ; ++it )
	containers.append( *it );
    list = containerArea->containers( "ExeButton" );
    for( QPtrListIterator<BaseContainer> it( list ); it.current() ; ++it )
	containers.append( *it );

    for( QPtrListIterator<BaseContainer> it( containers ); it.current() ; ++it ) {
	ButtonContainer* c = static_cast<ButtonContainer*>( it.current() );

	if ( it.current()->appletType() == "URLButton"
	    || it.current()->appletType() == "ServiceButton"
	    || it.current()->appletType() == "ExeButton" )
	    insertItem( SmallIcon( c->button()->icon() ), c->button()->title(), id );
	else if ( it.current()->appletType() == "ServiceMenuButton" )
	    insertItem( SmallIcon( c->button()->icon() ),
			i18n( "Menu: " ) + c->button()->title(), id );
	id++;
    }

    if ( containers.count() > 1 ) {
	insertSeparator();
	insertItem( i18n( "All" ), this, SLOT( slotRemoveAll() ) );
    }
}

void PanelRemoveButtonMenu::slotExec( int id )
{
    if ( containers.at( id ) )
	containerArea->removeContainer( containers.at( id ) );
}

PanelRemoveButtonMenu::~PanelRemoveButtonMenu()
{

}

void PanelRemoveButtonMenu::slotRemoveAll()
{
    for( QPtrListIterator<BaseContainer> it( containers ); it.current() ; ++it )
	containerArea->removeContainer( it.current() );
}

==> kdebase-3.2.3.tar.bz2: kdebase-3.2.3/kicker/ui/removebutton_mnu.cpp <==
/*****************************************************************

Copyright (c) 2001 Matthias Elter <elter@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#include <qregexp.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kglobal.h>
#include <kdebug.h>

#include "panelbutton.h"
#include "pluginmanager.h"
#include "pluginloader.h"
#include "containerarea.h"
#include "container_base.h"
#include "container_button.h"

#include "panelmenuiteminfo.h"
#include "removebutton_mnu.h"
#include "removebutton_mnu.moc"

PanelRemoveButtonMenu::PanelRemoveButtonMenu( ContainerArea* cArea,
                                              QWidget *parent, const char *name )
    : QPopupMenu( parent, name ), containerArea( cArea )
{
    connect( this, SIGNAL( activated( int ) ), SLOT( slotExec( int ) ) );
    connect( this, SIGNAL( aboutToShow() ), SLOT( slotAboutToShow() ) );

    containers.setAutoDelete( FALSE );
}

void PanelRemoveButtonMenu::slotAboutToShow()
{
    int id = 0;
    clear();

    QValueList<PanelMenuItemInfo> items;

    containers = containerArea->containers( "URLButton" );
    QPtrList<BaseContainer> list = containerArea->containers( "ServiceButton" );
    for( QPtrListIterator<BaseContainer> it( list ); it.current() ; ++it )
        containers.append( *it );
    list = containerArea->containers( "ServiceMenuButton" );
    for( QPtrListIterator<BaseContainer> it( list ); it.current() ; ++it )
        containers.append( *it );
    list = containerArea->containers( "ExeButton" );
    for( QPtrListIterator<BaseContainer> it( list ); it.current() ; ++it )
        containers.append( *it );

    for( QPtrListIterator<BaseContainer> it( containers ); it.current() ; ++it ) {
        ButtonContainer* c = static_cast<ButtonContainer*>( it.current() );

        if ( it.current()->appletType() == "URLButton"
                || it.current()->appletType() == "ServiceButton"
                || it.current()->appletType() == "ExeButton" )
            items.append( PanelMenuItemInfo( c->button()->icon(), c->button()->title(), id ) );
        else if ( it.current()->appletType() == "ServiceMenuButton" )
            items.append(PanelMenuItemInfo(c->button()->icon(),
                        i18n( "Menu: %1" ).arg(c->button()->title()), id ));
        id++;
    }

    qHeapSort(items);
    QValueList<PanelMenuItemInfo>::iterator it = items.begin();
    for (; it != items.end(); ++it)
    {
        (*it).plug(this);
    }

    if ( containers.count() > 1 ) {
        insertSeparator();
        insertItem( i18n( "All" ), this, SLOT( slotRemoveAll() ) );
    }
}

void PanelRemoveButtonMenu::slotExec( int id )
{
    if ( containers.at( id ) )
        containerArea->removeContainer( containers.at( id ) );
}

PanelRemoveButtonMenu::~PanelRemoveButtonMenu()
{

}

void PanelRemoveButtonMenu::slotRemoveAll()
{
    for( QPtrListIterator<BaseContainer> it( containers ); it.current() ; ++it )
        containerArea->removeContainer( it.current() );
}
